{ config, lib, modulesPath, ... }:
{
  boot = {
    initrd = {
      availableKernelModules = [
        "nvme"
        "xhci_pci"
        "ahci"
        "usbhid"
        "usb_storage"
        "sd_mod"
      ];
      kernelModules = [
        "dm-snapshot"
        "vfio"
        "vfio_pci"
        "vfio_iommu_type1"
        "kvm-amd"
      ];
    };
  };

  fileSystems = {
    # Useful system mounts
    "/etc/libvirt" = {
      device = "/dev/disk/by-uuid/f18a0302-9914-471d-828c-85ab1a67a8be";
      options = [ "nosuid" "nodev" "nofail" ];
    };
    "/etc/libvirt/VMs/Bulk" = {
      depends = [ "/etc/libvirt" ];
      device = "/dev/disk/by-uuid/3eb36c3e-81ac-4281-89f0-c89242d88dd6";
      options = [ "nosuid" "nodev" "nofail" ];
    };
    "/var/lib/libvirt" = {
      depends = [ "/etc/libvirt" ];
      device = "/etc/libvirt/varlibvirt";
      options = [ "bind" "rw" ];
    };

    # Games and such
    "/mnt/Linux1" = {
      device = "/dev/disk/by-uuid/b2901f8c-ffda-4b88-bb63-a9ea0c96ccb4";
      options = [ "nosuid" "nodev" "nofail" "x-gvfs-show" ];
    };
    "/mnt/Linux2" = {
      device = "/dev/disk/by-uuid/f08e4f38-162c-402f-ba2a-5925151b78bf";
      options = [ "nosuid" "nodev" "nofail" "x-gvfs-show" ];
    };
    "/mnt/Windows1" = {
      device = "/dev/disk/by-uuid/10BC97B2BC979138";
      options = [ "nosuid" "nodev" "noauto" ];
    };
    "/mnt/Windows2" = {
      device = "/dev/disk/by-uuid/0A5A3420237C863A";
      options = [ "nosuid" "nodev" "noauto" ];
    };

    # Network mounts
    "/home/jimbo/JimboNFS" = {
      device = "${config.ips.server}:/export/JimboNFS";
      fsType = "nfs4";
      options = [ "x-systemd.automount" "_netdev" "nofail" "noauto" ];
    };
  };

  swapDevices = [
    { device = "/dev/nixos/swap"; }
  ];

  networking.useDHCP = lib.mkDefault true;
  nixpkgs.hostPlatform = lib.mkDefault "x86_64-linux";
  hardware.cpu.amd.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
}
